Installation
============

Stable release
--------------

To install UNO Physics Tools, run this command in your terminal:

``` {.sourceCode .console}
$ pip install unophysics
```

This is the preferred method to install UNO Physics Tools, as it will
always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python
installation
guide](http://docs.python-guide.org/en/latest/starting/installation/)
can guide you through the process.

From sources
------------

The sources for UNO Physics Tools can be downloaded from the [Github
repo](https://github.com/micha2718l/unophysics).

You can either clone the public repository:

``` {.sourceCode .console}
$ git clone git://github.com/micha2718l/unophysics
```

Or download the
[tarball](https://github.com/micha2718l/unophysics/tarball/master):

``` {.sourceCode .console}
$ curl  -OL https://github.com/micha2718l/unophysics/tarball/master
```

Once you have a copy of the source, you can install it with:

``` {.sourceCode .console}
$ python setup.py install
```
